@@ -1,8 +1,8 @@
 /*
  * command.c
  *
- * All rights reserved. Copyright (C) 1996-1999 by NARITA Tomio.
- * $Id: command.c,v 1.14 2000/06/26 11:36:43 nrt Exp $
+ * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
+ * $Id: command.c,v 1.19 2003/11/14 04:50:37 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 
 #ifdef MSDOS
 #include <dos.h>
@@ -106,7 +108,10 @@ public boolean_t CommandInit()
 {
   int i;
 
-  editor_program = "vi -c %d";
+  if ((!(editor_program = getenv("VISUAL"))) &&
+      (!(editor_program = getenv("EDITOR")))) {
+    editor_program = "vi -c %d";
+  }
 
   historyIndex = 0;
   for( i = 0 ; i < HISTORY_SIZE ; i++ )
@@ -601,7 +606,10 @@ private int CommandLaunchEditor( byte *editor, byte *filename, int line )
   } else if( -1 == pid ){
     return 1;
   } else {
-    wait( &status );
+    int rv;
+    do {
+	rv = wait( &status );
+    } while (rv == -1 && errno == EINTR);
     return status;
   }
 #endif /* MSDOS */
@@ -686,6 +694,62 @@ private void CommandBottomOfFile( unsigned int arg )
     DisplayFull( f );
 }
 
+private void CommandPoll( unsigned int arg )
+{
+  long pos;
+
+  kb_interrupted = FALSE;
+
+  if( NULL != f->sp ){
+    label = "cannot poll non-regular files";
+    return;
+  }
+
+  if( access( f->fileName, 0 ) ){
+    label = "cannot access current file";
+    return;
+  }
+
+  while( 1 ){
+    CommandReload(arg);
+    CommandBottomOfFile( arg );
+    ConsoleGoAhead();
+    ConsoleClearRight();
+    ConsoleSetAttribute( ATTR_STANDOUT );
+    ConsolePrints( "Waiting for data, break (^C) to return..." );
+    ConsoleSetAttribute( NULL );
+    ConsoleFlush();
+
+    (void)fseek( f->fp, 0, SEEK_END );
+    pos = ftell( f->fp );
+
+    ConsoleEnableInterrupt();
+
+    while( 1 ){
+      usleep(300000); // 300msec
+      if( kb_interrupted )
+	break;
+
+      (void)fseek( f->fp, 0, SEEK_END );
+      if( ftell( f->fp ) > pos ){
+	// it grew
+	break;
+      }
+    }
+
+    ConsoleDisableInterrupt();
+
+    if( kb_interrupted )
+      break;
+  }
+
+  // execute that just to be sure, also it will clear the
+  // "waiting..." message.
+  kb_interrupted = FALSE;
+  CommandReload(arg);
+  CommandBottomOfFile(arg);
+}
+
 private void CommandPrev( unsigned int arg )
 {
   if( 0 < (arg = ScreenPrev( f, arg )) )
