@@ -1,8 +1,8 @@
 /*
  * conf.c
  *
- * All rights reserved. Copyright (C) 1996-1999 by NARITA Tomio.
- * $Id: conf.c,v 1.9 2000/06/26 11:37:27 nrt Exp $
+ * All rights reserved. Copyright (C) 1998 by NARITA Tomio.
+ * $Id: conf.c,v 1.15 2003/11/13 03:22:52 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -38,15 +38,19 @@
 #include <conv.h>
 #include <uty.h>
 #include <version.h>
+#ifdef HAVE_SETLOCALE
+#include <locale.h>
+#include <guesslocale.h>
+#endif
 #include <begin.h>
 #include <conf.h>
 
 #define DEFAULT_INPUT_CODING_SYSTEM	AUTOSELECT
 
 #ifdef UNIX
-#define DEFAULT_OUTPUT_CODING_SYSTEM	ISO_2022_JP	/* ja specific */
-#define DEFAULT_KEYBOARD_CODING_SYSTEM	ISO_2022_JP
-#define DEFAULT_PATHNAME_CODING_SYSTEM	ISO_2022_JP
+#define DEFAULT_OUTPUT_CODING_SYSTEM	EUC_JAPAN	/* ja specific */
+#define DEFAULT_KEYBOARD_CODING_SYSTEM	EUC_JAPAN
+#define DEFAULT_PATHNAME_CODING_SYSTEM	EUC_JAPAN
 #define DEFAULT_DEFAULT_CODING_SYSTEM	EUC_JAPAN
 
 #define LV_CONF		".lv"
@@ -70,16 +74,39 @@ private byte *lvHelpFile[ 2 ];
 
 private void ConfInitArgs( conf_t *conf )
 {
+#ifdef HAVE_SETLOCALE
+  byte localeCodingSystem;
+  char dummy[6];
+  char *nl;
+  int use_locale = 1;
+
+  nl = setlocale( LC_CTYPE, "" );
+  if (NULL == nl || !strcmp("C", nl))
+    use_locale = 0;
+  else
+    localeCodingSystem = LocaleCodingSystem(dummy);
+#endif
+
   conf->file	= NULL;
   conf->st	= NULL;
   conf->width	= -1;
   conf->height	= -1;
   conf->options	= TRUE;
   conf->inputCodingSystem	= DEFAULT_INPUT_CODING_SYSTEM;
-  conf->keyboardCodingSystem	= DEFAULT_KEYBOARD_CODING_SYSTEM;
-  conf->outputCodingSystem	= DEFAULT_OUTPUT_CODING_SYSTEM;
-  conf->pathnameCodingSystem	= DEFAULT_PATHNAME_CODING_SYSTEM;
-  conf->defaultCodingSystem	= DEFAULT_DEFAULT_CODING_SYSTEM;
+#ifdef HAVE_SETLOCALE
+  if (use_locale) {
+    conf->keyboardCodingSystem	= localeCodingSystem;
+    conf->outputCodingSystem	= localeCodingSystem;
+    conf->pathnameCodingSystem	= localeCodingSystem;
+    conf->defaultCodingSystem	= localeCodingSystem;
+  } else
+#endif
+  {
+    conf->keyboardCodingSystem	= DEFAULT_KEYBOARD_CODING_SYSTEM;
+    conf->outputCodingSystem	= DEFAULT_OUTPUT_CODING_SYSTEM;
+    conf->pathnameCodingSystem	= DEFAULT_PATHNAME_CODING_SYSTEM;
+    conf->defaultCodingSystem	= DEFAULT_DEFAULT_CODING_SYSTEM;
+  }
   conf->keyCodingSystemVirgin	= TRUE;
 
 #ifndef MSDOS /* IF NOT DEFINED */
@@ -140,6 +167,12 @@ private void SetCodingSystem( byte *s, byte *codingSystem, byte *location )
     case '7': *codingSystem = ISO_8859_7;	break;
     case '8': *codingSystem = ISO_8859_8;	break;
     case '9': *codingSystem = ISO_8859_9;	break;
+    case '0': *codingSystem = ISO_8859_10;	break;
+    case 'b': *codingSystem = ISO_8859_11;	break;
+    case 'd': *codingSystem = ISO_8859_13;	break;
+    case 'e': *codingSystem = ISO_8859_14;	break;
+    case 'f': *codingSystem = ISO_8859_15;	break;
+    case 'g': *codingSystem = ISO_8859_16;	break;
     default:
       *codingSystem = ISO_8859_1;
     }
@@ -186,10 +219,13 @@ private void SetAnsiSequence( byte *s, byte *location )
 private void ConfArg( conf_t *conf, byte **argv, byte *location )
 {
   byte *s, quotationChar;
+#ifdef HAVE_SETLOCALE
+  char dummy[6];
+#endif
 
   if( TRUE == conf->options && '-' == **argv ){
     s = *argv + 1;
-    if( NULL == *s )
+    if( '\0' == *s )
       conf->options = FALSE;
     while( *s ){
       switch( *s ){
@@ -206,7 +242,14 @@ private void ConfArg( conf_t *conf, byte **argv, byte *location )
 	  SetCodingSystem( s, &conf->inputCodingSystem, location );
 	break;
       case 'O':
+#ifdef HAVE_SETLOCALE
+	if( 'a' == *( s + 1 ) )
+	  conf->outputCodingSystem = LocaleCodingSystem(dummy);
+	else
+	  SetCodingSystem( s, &conf->outputCodingSystem, location );
+#else
 	SetCodingSystem( s, &conf->outputCodingSystem, location );
+#endif
 	break;
       case 'K':
 	SetCodingSystem( s, &conf->keyboardCodingSystem, location );
@@ -226,7 +269,7 @@ private void ConfArg( conf_t *conf, byte **argv, byte *location )
 	  quotationChar = *( s + 1 );
 	  editor_program = TokenAlloc( s + 1 );
 	  s += 2;
-	  while( NULL != *s && quotationChar != *s )
+	  while( '\0' != *s && quotationChar != *s )
 	    s++;
 	} else {
 	  editor_program = Malloc( strlen( s + 1 ) + 1 );
@@ -325,7 +368,7 @@ private void ConfFile( conf_t *conf, byte *file )
       continue;
     for( i = strlen( buf ) - 1 ; i >= 0 ; i-- ){
       if( buf[ i ] < SP )
-	buf[ i ] = NULL;
+	buf[ i ] = '\0';
       else
 	break;
     }
@@ -348,7 +391,9 @@ public void Conf( conf_t *conf, byte **argv )
     ConfFile( conf, buf );
   }
 
+#ifdef MSDOS
   ConfFile( conf, LV_CONF );
+#endif
 
   if( NULL != (*argv = getenv( "LV" )) )
     ConfArg( conf, argv, "environment" );
