@@ -1,8 +1,8 @@
 /*
  * console.c
  *
- * All rights reserved. Copyright (C) 1996-1999 by NARITA Tomio.
- * $Id: console.c,v 1.5 2000/06/26 11:39:29 nrt Exp $
+ * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
+ * $Id: console.c,v 1.7 2003/11/13 03:08:19 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,9 @@
 #endif /* MSDOS */
 
 #ifdef UNIX
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include <unistd.h>
 #ifdef HAVE_TERMIOS_H
 #include <termios.h>
@@ -289,11 +292,23 @@ public void ConsoleTermInit()
 
 #ifdef TERMCAP
   byte *term, *ptr;
+#endif
+#ifdef TERMINFO
+  byte *term;
+  int state;
+#endif
 
+#ifdef UNIX
+  int fd = open("/dev/tty", O_RDONLY);
+  dup2(fd, 0);
+  close(fd);
+#endif
+
+#ifdef TERMCAP
   if( NULL == (term = getenv( "TERM" )) )
-    fprintf( stderr, "lv: environment variable TERM is required\n" ), exit( -1 );
+    fprintf( stderr, "lv: environment variable TERM is required\n" );
   if( 0 >= tgetent( entry, term ) )
-    fprintf( stderr, "lv: %s not found in termcap\n", term ), exit( -1 );
+    fprintf( stderr, "lv: %s not found in termcap\n", term );
 
   ConsoleGetWindowSize();
 
@@ -326,7 +341,7 @@ public void ConsoleTermInit()
   cur_npage		= tgetstr( "kN", &ptr );
 
   if( NULL == cursor_address || NULL == clear_screen || NULL == clr_eol )
-    fprintf( stderr, "lv: termcap cm, cl, ce are required\n" ), exit( -1 );
+    fprintf( stderr, "lv: termcap cm, cl, ce are required\n" );
 
   if( NULL == insert_line || NULL == delete_line )
     no_scroll = TRUE;
@@ -335,15 +350,13 @@ public void ConsoleTermInit()
 #endif /* TERMCAP */
 
 #ifdef TERMINFO
-  byte *term;
-  int state;
 
   if( NULL == (term = getenv( "TERM" )) )
-    fprintf( stderr, "lv: environment variable TERM is required\n" ), exit( -1 );
+    fprintf( stderr, "lv: environment variable TERM is required\n" );
 
   setupterm( term, 1, &state );
   if( 1 != state )
-    fprintf( stderr, "lv: cannot initialize terminal\n" ), exit( -1 );
+    fprintf( stderr, "lv: cannot initialize terminal\n" );
 
   ConsoleGetWindowSize();
 
@@ -355,7 +368,7 @@ public void ConsoleTermInit()
   cur_npage		= key_npage;
 
   if( NULL == cursor_address || NULL == clear_screen || NULL == clr_eol )
-    fprintf( stderr, "lv: terminfo cursor_address, clr_eol are required\n" ), exit( -1 );
+    fprintf( stderr, "lv: terminfo cursor_address, clr_eol are required\n" );
 
   if( NULL == insert_line || NULL == delete_line )
     no_scroll = TRUE;
